@@ -3,11 +3,11 @@
 set -eu
 
 PAM_USER_UID="$(id -u -- "$PAM_USER")"
-LOCAL_HOME_PATH="/local_home/$PAM_USER_UID"
+LOCAL_HOME_PATH="/local/home/$PAM_USER_UID"
 
 umask 0022
 
-/bin/mkdir -p "/local_home"
+/bin/mkdir -p "/local/home"
 
 umask 0077
 /bin/mkdir -p "$LOCAL_HOME_PATH"
